Support
=======

Usage Questions
~~~~~~~~~~~~~~~

If you have questions about how to use Niapy or have an issue that isn’t related to a bug, you can place 
a question on `StackOverflow <https://stackoverflow.com/>`_.

You can also join us at our `Slack Channel <https://join.slack.com/t/niaorg/shared_invite/enQtMzExMTU2MzM1OTg4LTFlYTUxZDcwZTU4ZTBjZDgzZWE3ZTM5MjE3MjVjOTllNTNmYTVjNjE5ZTEzYTU0YTc4OTJiNWI2MDNiZjY2YjQ>`_ or seek support via niapy.organization@gmail.com.

NiaPy is a community supported package, nobody is paid to develop package nor to handle NiaPy support.

**All people answering your questions are doing it with their own time, so please be kind and provide as 
much information as possible.**

Reporting bugs
~~~~~~~~~~~~~~

`Check out Reporting bugs section in Contributing to NiaPy <contributing_to_niapy.html#reporting-bugs>`__
